# Aggregated CM and CMX automations for MLOps and MLPerf

[![License](https://img.shields.io/badge/License-Apache%202.0-green)](LICENSE.md)
[![Powered by CM/CMX](https://img.shields.io/badge/Powered_by-MLCommons%20CM-blue)](https://pypi.org/project/cmind).

This repository is powered by the [Collective Mind workflow automation framework](https://github.com/mlcommons/ck/tree/master/cm).

Two key automations developed using CM are **Script** and **Cache**, which streamline machine learning (ML) workflows, 
including managing Docker runs. Both Script and Cache automations are part of the **cmx4mlops** repository.

The [CM scripts](https://access.cknowledge.org/playground/?action=scripts), 
also housed in this repository, consist of hundreds of modular Python-wrapped scripts accompanied 
by `yaml` metadata, enabling the creation of robust and flexible ML workflows.

## License

[Apache 2.0](LICENSE.md)

## Copyright

© 2022-2025 MLCommons. All Rights Reserved.

Grigori Fursin, the cTuning foundation and OctoML donated the CK and CM projects to MLCommons to benefit everyone and encourage collaborative development.

## Maintainer(s)

* MLCommons

## Author

[Grigori Fursin](https://cKnowledge.org/gfursin)

We sincerely appreciate all [contributors](https://github.com/mlcommons/ck/blob/master/CONTRIBUTORS.md) 
for their invaluable feedback and support!

## Concepts

Check our [ACM REP'23 keynote](https://doi.org/10.5281/zenodo.8105339) and the [white paper](https://arxiv.org/abs/2406.16791).

## Parent project

Visit the [parent Collective Knowledge project](https://github.com/mlcommons/ck) for further details.

## Citing this project

If you found the CM automations helpful, kindly reference this article:
[ [ArXiv](https://arxiv.org/abs/2406.16791) ]
